@@ -12,7 +12,7 @@ const { $require } = require('./deps')
 const { once } = require('events')
 
 const debug = process.env.DEBUG?.includes('jspybridge') ? console.debug : () => { }
-const colors = process.env.FORCE_COLOR !== '0'
+const supportsColors = process.env.FORCE_COLOR !== '0'
 
 function getType (obj) {
   if (obj?.ffid) return 'py'
@@ -35,6 +35,7 @@ function getType (obj) {
     return 'fn'
   }
   if (typeof obj === 'bigint') return 'big'
+  if (obj === null) return 'void'
   if (typeof obj === 'object') return 'obj'
   if (!isNaN(obj)) return 'num'
   if (typeof obj === 'string') return 'string'
@@ -162,7 +163,8 @@ class Bridge {
   }
 
   // called for debug in JS, print() in python via __str__
-  async inspect (r, ffid) {
+  async inspect (r, ffid, mode) {
+    const colors = supportsColors && (mode === 'str')
     const s = util.inspect(await this.m[ffid], { colors })
     this.ipc.send({ r, val: s })
   }
@@ -262,15 +264,38 @@ const ipc = {
 }
 
 const bridge = new Bridge(ipc)
+let message = ''
 process.stdin.on('data', data => {
   const d = String(data)
-  debug('py -> js', d)
-  for (const line of d.split('\n')) {
-    try { var j = JSON.parse(line) } catch (e) { continue } // eslint-disable-line
-    if (j.c === 'pyi') {
-      handlers[j.r]?.(j)
+  for (let i = 0; i < d.length; i++) {
+    if (d[i] === '\n') {
+      debug('py -> js', message)
+      for (const line of message.split('\n')) {
+        try { var j = JSON.parse(line) } catch (e) { continue } // eslint-disable-line
+        if (j.c === 'pyi') {
+          handlers[j.r]?.(j)
+        } else {
+          bridge.onMessage(j)
+        }
+      }
+      message = ''
     } else {
-      bridge.onMessage(j)
+      message += d[i]
+    }
+  }
+})
+
+// flush last line
+process.stdin.on('end', () => {
+  if (message.length > 0) {
+    debug('py -> js', message)
+    for (const line of message.split('\n')) {
+        try { var j = JSON.parse(line) } catch (e) { continue } // eslint-disable-line
+      if (j.c === 'pyi') {
+        handlers[j.r]?.(j)
+      } else {
+        bridge.onMessage(j)
+      }
     }
   }
 })
